@@ -4,6 +4,12 @@ import core.models
 
 
 class Cliente(core.models.Log, core.models.PessoaLog):
+    """
+    :Nome da classe/função: Cliente
+    :descrição: Classe de clientes
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     cpf = models.BigIntegerField(primary_key=True)
     imagem = models.FileField(upload_to='fotos/clientes', default='fotos/sem-foto.png', null=True)
 
@@ -20,6 +26,12 @@ class Cliente(core.models.Log, core.models.PessoaLog):
 
 
 class Endereco(core.models.Log, core.models.EnderecoComplementoLog):
+    """
+    :Nome da classe/função: Endereco
+    :descrição: Classe de enderecos de clientes
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)
     codigo = models.IntegerField(default=1, null=True)
     is_principal = models.BooleanField(default=True, null=True)
@@ -40,6 +52,12 @@ class Endereco(core.models.Log, core.models.EnderecoComplementoLog):
 
 
 class Cartao(core.models.Log):
+    """
+    :Nome da classe/função: Cartao
+    :descrição: Classe de cartoes de clientes
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)
     cliente_token = models.CharField(max_length=200, null=True)
     cartao_id = models.CharField(max_length=50, null=True)
@@ -80,6 +98,12 @@ class Cartao(core.models.Log):
 
 
 class CartaoBandeira(core.models.Log):
+    """
+    :Nome da classe/função: CartaoBandeira
+    :descrição: Classe de bandeiras de cartoes
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     nome = models.CharField(max_length=50, primary_key=True)
     nm_descritivo = models.CharField(max_length=200, null=True)
     imagem = models.FileField(upload_to="bandeiras", default='bandeiras/sem-imagem.jpg', null=True)
@@ -90,6 +114,12 @@ class CartaoBandeira(core.models.Log):
 
 
 class CartaoBandeiraParcela(core.models.Log):
+    """
+    :Nome da classe/função: CartaoBandeiraParcela
+    :descrição: Classe de parcelas de bandeiras de cartões
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     bandeira = models.ForeignKey('cliente.CartaoBandeira', on_delete=models.DO_NOTHING, null=True)
     quantidade = models.IntegerField(default=1, null=True)
     is_juros = models.BooleanField(default=False, null=True)
@@ -100,6 +130,12 @@ class CartaoBandeiraParcela(core.models.Log):
 
 
 class Termo(core.models.Log):
+    """
+    :Nome da classe/função: Termo
+    :descrição: Classe de termos para clientes
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     nome = models.CharField(max_length=200, primary_key=True)
     nome_descritivo = models.CharField(max_length=200, null=True)
     nome_html = models.CharField(max_length=500, null=True)
@@ -123,6 +159,12 @@ class Termo(core.models.Log):
 
 
 class ClienteTermo(core.models.Log):
+    """
+    :Nome da classe/função: ClienteTermo
+    :descrição: Classe de relação entre cliente e termos
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     termo = models.ForeignKey('cliente.Termo', on_delete=models.DO_NOTHING, null=True)
     cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)
 
@@ -132,6 +174,12 @@ class ClienteTermo(core.models.Log):
 
 
 class Receita(core.models.Log):
+    """
+    :Nome da classe/função: Receita
+    :descrição: Classe de relação entre cliente e receitas
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)
 
     class Meta(core.models.Log.Meta):
@@ -140,6 +188,12 @@ class Receita(core.models.Log):
 
 
 class Avaliacao(core.models.Log):
+    """
+    :Nome da classe/função: Avaliacao
+    :descrição: Classe de relação entre cliente e avaliações
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)
 
     class Meta(core.models.Log.Meta):
@@ -148,6 +202,12 @@ class Avaliacao(core.models.Log):
 
 
 class Favorito(core.models.Log):
+    """
+    :Nome da classe/função: Favorito
+    :descrição: Classe de relação entre cliente e favoritos
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)
 
     class Meta(core.models.Log.Meta):
@@ -156,6 +216,12 @@ class Favorito(core.models.Log):
 
 
 class Cupom(core.models.Log):
+    """
+    :Nome da classe/função: Cupom
+    :descrição: Classe de relação entre cliente e cupons
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)
 
     class Meta(core.models.Log.Meta):
